==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapComponentEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapComponentEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapComponentEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapComponentEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapComponentEntity> entityFieldDelegate;
    public MapComponentEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapComponentEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapComponentEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProviderId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setProviderId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProviderType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setProviderType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getSubType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.SUB_TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setSubType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.SUB_TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getParentId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.PARENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setParentId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.PARENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> getConfig() {
        return (java.util.Map<String,java.util.List<String>>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(java.util.Map<String,java.util.List<String>> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.CONFIG, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapComponentEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapComponentEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapComponentEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapComponentEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapComponentEntity> entityFieldDelegate;
    public MapComponentEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapComponentEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapComponentEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProviderId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setProviderId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProviderType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setProviderType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getSubType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.SUB_TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setSubType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.SUB_TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getParentId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.PARENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setParentId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.PARENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> getConfig() {
        return (java.util.Map<String,java.util.List<String>>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapComponentEntityFields.CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(java.util.Map<String,java.util.List<String>> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapComponentEntityFields.CONFIG, p0);
    }
}
